@@ -12,15 +12,13 @@ embed.aov <- function(x, ina) {
 
   ina <- as.numeric(ina)
   g <- max(ina)  ## how many groups are there
-  ni <- as.vector(table(ina))
-  x <- as.matrix(x)
-  x <- x / sqrt( Rfast::rowsums(x^2) )   ## makes sure x are unit vectors
+  ni <- tabulate(ina)
   p <- dim(x)[2]  ## dimensionality of the data
   n <- dim(x)[1]  ## sample size of the data
 
   S <- rowsum(x, ina) / ni
   Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
-  S <- Rfast::colmeans(x) 
+  S <- Rfast::colmeans(x)
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
 
   Ft <-  (n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) *
