@@ -12,16 +12,16 @@ embed.circaov <- function(u, ina, rads = FALSE) {
 
   n <- length(u)  ## sample size
   ina <- as.numeric(ina)
-  ni <- as.vector(table(ina))
+  ni <- tabulate(ina)
   g <- max(ina)  ## how many groups are there
   ## if the data are in degrees we transform them into radians
 
-  if ( rads == FALSE )  u <- u * pi/180
+  if ( !rads )  u <- u * pi/180
   x1 <- cos(u)
   x2 <- sin(u)
   Ci <- rowsum(x1, ina)
   Si <- rowsum(x2, ina)
-  Rbi <- sqrt( Ci^2 + Si^2 )/ni
+  Rbi <- ( Ci^2 + Si^2 )/ni^2
 
   C <- sum(Ci)
   S <- sum(Si)
@@ -31,8 +31,8 @@ embed.circaov <- function(u, ina, rads = FALSE) {
   kappa <- circ.summary(u, rads = TRUE, plot = FALSE)$kappa
   ## kappa is the estimated concentration parameter based on all the data
 
-  Fb <- ( (sum(ni * Rbi^2) - n * Rbar^2 )/(g - 1) ) /
-    ( (n - sum(ni * Rbi^2) )/(n - g) )
+  Fb <- ( (sum(ni * Rbi) - n * Rbar^2 )/(g - 1) ) /
+    ( (n - sum(ni * Rbi) )/(n - g) )
   Fc <- ( 1 - 1/(5 * kappa) - 1/(10 * kappa^2) ) * Fb
   pvalue <- pf(Fc, g - 1, n - g, lower.tail = FALSE)
   res <- c(Fc, pvalue, kappa)
