@@ -31,14 +31,13 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
     mat <- matrix( nu, ncol = M )
   } else  mat <- mat
 
-  M <- ncol(mat)
-  rmat <- nrow(mat)
+  M <- dim(mat)[2]
+  rmat <- dim(mat)[1]
   per <- matrix(nrow = M, ncol = A - 1)
 
   if (type == "spher") {
 
     runtime <- proc.time()
-    x <- x / sqrt( Rfast::rowsums(x^2) )  ## makes sure x are unit vectors
     apostasi <- tcrossprod( x )
     diag(apostasi) <- 1
     apostasi[ apostasi >= 1 ] <- 1
@@ -65,7 +64,7 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
             qan <- xa[order(xa[, 2]), ]
             a <- qan[1:k, 1]
             yb <- as.matrix( y[a, ] )
-            est[i, ] <- Rfast::colmeans( yb ) 
+            est[i, ] <- Rfast::colmeans( yb )
           }
 
         } else if (estim == "harmonic") {
@@ -74,25 +73,23 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
             qan <- xa[order(xa[, 2]), ]
             a <- qan[1:k, 1]
             yb <- as.matrix( y[a, ] )
-            est[i, ] <- k / Rfast::colsums( yb ) 
+            est[i, ] <- k / Rfast::colsums( yb )
           }
         }
 
         if (res == "spher") {
-          est <- est / sqrt( Rfast::rowsums(est^2) ) 
-          ytest <- ytest / sqrt( Rfast::rowsums(ytest^2) ) 
+          est <- est / sqrt( Rfast::rowsums(est^2) )
           per[vim, l] <- 1 - sum( est * ytest )  / rmat
-        } else  {
-          per[vim, l] <- sum( (est - ytest)^2 ) / rmat
-        }
+        } else  per[vim, l] <- sum( (est - ytest)^2 ) / rmat
+
       }
     }
 
-    mspe <- Rfast::colmeans(per) 
-    bias <- per[ ,which.min(mspe)] - apply(per, 1, min)  ## TT estimate of bias
+    mspe <- Rfast::colmeans(per)
+    bias <- per[ , which.min(mspe)] - Rfast::rowMins(per, value = TRUE) ## apply(per, 1, min)  ## TT estimate of bias
     estb <- mean( bias )  ## TT estimate of bias
     performance <- c( 1 - min(mspe) + estb, estb)
-    mspe <- 1 - Rfast::colmeans(per) 
+    mspe <- 1 - Rfast::colmeans(per)
     runtime <- proc.time() - runtime
 
   } else {
@@ -122,8 +119,8 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
       registerDoParallel(cl)
       pe <- numeric(A - 1)
 
-      per <- foreach(i = 1:M, .combine = rbind, .packages = "Rfast", 
-	  .export = c("knn.reg", "rowsums", "colmeans", "colVars", "colsums") ) %dopar% {
+      per <- foreach(i = 1:M, .combine = rbind, .packages = "Rfast",
+	     .export = c("knn.reg", "rowsums", "colmeans", "colVars", "colsums") ) %dopar% {
         ytest <- as.matrix( y[mat[, i], ] )  ## test set dependent vars
         ytrain <- as.matrix( y[-mat[, i], ] )  ## train set dependent vars
         xtrain <- as.matrix( x[-mat[, i], ] )  ## train set independent vars
@@ -141,7 +138,7 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
     }
 
     mspe <- Rfast::colmeans(per)
-    bias <- per[ ,which.min(mspe)] - apply(per, 1, min)  ## TT estimate of bias
+    bias <- per[ ,which.min(mspe)] - Rfast::rowMins(per, value = TRUE)## apply(per, 1, min)  ## TT estimate of bias
     estb <- mean( bias )  ## TT estimate of bias
     names(mspe) <- paste("k=", 2:A, sep = "")
     performance <- c( min(mspe) + estb, estb)
@@ -149,7 +146,7 @@ knnreg.tune <- function(y, x, M = 10, A = 10, ncores = 1, res = "eucl",
 
   }
 
-  if (graph == TRUE) {
+  if ( graph ) {
     plot(2:c(length(mspe) + 1), mspe, xlab = "Nearest neighbours",
     ylab = "MSPE", type = "b")
   }
