@@ -9,18 +9,17 @@
 vmfkde.tune <- function(x, low = 0.1, up = 1) {
   ## x is the data
 
-  x <- as.matrix(x)  ## makes sure x is a matrix
-  x <- x / sqrt( Rfast::rowsums(x^2) )  ## makes sure x is directional data
   p <- dim(x)[2]  ## dimensionality of the data
   n <- dim(x)[1]  ## sample size of the data
   d <- tcrossprod( x )
   diag(d) <- NA  ##  we do not want to take the diagonal elements
+  con <- (2 * pi)^(p/2)
 
    funa <- function(h) {
     A <- d/h^2
-    cpk <- (1/h^2)^(p/2 - 1) / ( (2 * pi)^(p/2) * besselI(1/h^2, p/2 - 1) )
-    f <- rowSums( exp(A + log(cpk)), na.rm = TRUE ) / (n - 1) 
-    sum( log(f) ) / n
+    cpk <- (1/h^2)^(p/2 - 1) / con / besselI(1/h^2, p/2 - 1)
+    f <- rowSums( exp(A + log(cpk)), na.rm = TRUE )/(n - 1)
+    mean( log(f) )
   }
 
   a <- optimize(funa, c(low, up), maximum = TRUE)
